Crate egui_baseview

Crate egui_baseview 

Re-exports

pub use baseview;

Structs

EguiWindow
Handles an egui-baseview application
EguiWindowSettings
Settings used when creating a new window
Frame
Represents the surroundings of your app.
GraphicsConfig
RepaintNotifier
A realtime-safe handle to request a update & repaint for an egui app.

Enums

Key
The value received from the keypress.
KeyCapture
Describes how to handle capturing key events from the host.

Traits

App
Implement this trait to run an app with egui-baseview.