EguiWindow

Struct EguiWindow 

pub struct EguiWindow<State, U, O>
where State: 'static + Send, U: FnMut(&mut Ui, &mut ExtraOutputCommands, &mut State) + 'static + Send, O: FnMut(&FullOutput, &ViewportOutput, &mut State) + 'static + Send,
{ pub window: WindowContext, /* private fields */ }
Handles an egui-baseview application

Fields

window: WindowContext

Implementations

Source

impl<State, U, O> EguiWindow<State, U, O>
where State: 'static + Send, U: FnMut(&mut Ui, &mut ExtraOutputCommands, &mut State) + 'static + Send, O: FnMut(&FullOutput, &ViewportOutput, &mut State) + 'static + Send,

pub fn open_parented<P, B>( parent: &P, settings: EguiWindowSettings, state: State, build: B, output: O, update: U, ) -> WindowHandle
where P: HasWindowHandle, B: FnMut(&Context, &mut ExtraOutputCommands, &mut State) + 'static + Send,

Open a new child window.

  • parent - The parent window.
  • settings - The settings of the window.
  • state - The initial state of your application.
  • build - Called once before the first frame. Allows you to do setup code and to call ctx.set_fonts(). Optional.
  • output - Called after each update. Can be used to read egui’s output commands to perform actions, i.e. asking the host to resize the window if a command to resize the window is present. Optional.
  • update - Called before each frame. Here you should update the state of your application and build the UI.
pub fn open_blocking<B>( settings: EguiWindowSettings, state: State, build: B, output: O, update: U, )
where B: FnMut(&Context, &mut ExtraOutputCommands, &mut State) + 'static + Send,

Open a new window that blocks the current thread until the window is destroyed.

  • settings - The settings of the window.
  • state - The initial state of your application.
  • build - Called once before the first frame. Allows you to do setup code and to call ctx.set_fonts(). Optional.
  • output - Called after each update. Can be used to read egui’s output commands to perform actions, i.e. asking the host to resize the window if a command to resize the window is present. Optional.
  • update - Called before each frame. Here you should update the state of your application and build the UI.