Frame

Struct Frame 

pub struct Frame { /* private fields */ }
Represents the surroundings of your app.

Implementations

Source

impl Frame

pub fn set_clear_color(&mut self, clear_color: Rgba)

Set the clear color of the renderer.

pub fn set_key_capture(&mut self, key_capture: KeyCapture)

Set how to handle capturing key events from the host.

pub fn baseview_window(&self) -> &WindowContext

Access the internal baseview window.

pub fn gl(&self) -> &Arc<Context>

A reference to the underlying glow (OpenGL) context.

This can be used, for instance, to:

  • Render things to offscreen buffers.
  • Read the pixel buffer from the previous frame (glow::Context::read_pixels).
  • Render things behind the egui windows.

Note that all egui painting is deferred to after the call to App::ui (egui only collects egui::Shapes and then egui-baseview paints them all in one go later on).