pub struct RepaintNotifier { /* private fields */ }Expand description
A realtime-safe handle to request a update & repaint for an egui app.
This can be used, for example, to notify the GUI that the value of a decibel meter has changed.
Implementations
Sourceimpl RepaintNotifier
impl RepaintNotifier
pub fn new() -> Self
pub fn request_repaint(&self)
pub fn request_repaint_with(&self, repaint: bool)