pub struct EguiWindow<State, U, O>where
State: 'static + Send,
U: FnMut(&mut Ui, &mut ExtraOutputCommands, &mut State) + 'static + Send,
O: FnMut(&FullOutput, &ViewportOutput, &mut State) + 'static + Send,{
pub window: WindowContext,
/* private fields */
}Expand description
Handles an egui-baseview application
Fields
window: WindowContextImplementations
Sourceimpl<State, U, O> EguiWindow<State, U, O>where
State: 'static + Send,
U: FnMut(&mut Ui, &mut ExtraOutputCommands, &mut State) + 'static + Send,
O: FnMut(&FullOutput, &ViewportOutput, &mut State) + 'static + Send,
impl<State, U, O> EguiWindow<State, U, O>where
State: 'static + Send,
U: FnMut(&mut Ui, &mut ExtraOutputCommands, &mut State) + 'static + Send,
O: FnMut(&FullOutput, &ViewportOutput, &mut State) + 'static + Send,
Sourcepub fn open_parented<P, B>(
parent: &P,
settings: EguiWindowSettings,
state: State,
build: B,
output: O,
update: U,
) -> WindowHandlewhere
P: HasWindowHandle,
B: FnMut(&Context, &mut ExtraOutputCommands, &mut State) + 'static + Send,
pub fn open_parented<P, B>(
parent: &P,
settings: EguiWindowSettings,
state: State,
build: B,
output: O,
update: U,
) -> WindowHandlewhere
P: HasWindowHandle,
B: FnMut(&Context, &mut ExtraOutputCommands, &mut State) + 'static + Send,
Open a new child window.
parent- The parent window.settings- The settings of the window.state- The initial state of your application.build- Called once before the first frame. Allows you to do setup code and to callctx.set_fonts(). Optional.output- Called after eachupdate. Can be used to read egui’s output commands to perform actions, i.e. asking the host to resize the window if a command to resize the window is present. Optional.update- Called before each frame. Here you should update the state of your application and build the UI.
Sourcepub fn open_blocking<B>(
settings: EguiWindowSettings,
state: State,
build: B,
output: O,
update: U,
)
pub fn open_blocking<B>( settings: EguiWindowSettings, state: State, build: B, output: O, update: U, )
Open a new window that blocks the current thread until the window is destroyed.
settings- The settings of the window.state- The initial state of your application.build- Called once before the first frame. Allows you to do setup code and to callctx.set_fonts(). Optional.output- Called after eachupdate. Can be used to read egui’s output commands to perform actions, i.e. asking the host to resize the window if a command to resize the window is present. Optional.update- Called before each frame. Here you should update the state of your application and build the UI.