pub struct Frame { /* private fields */ }Expand description
Represents the surroundings of your app.
Implementations
Sourceimpl Frame
impl Frame
Sourcepub fn set_clear_color(&mut self, clear_color: Rgba)
pub fn set_clear_color(&mut self, clear_color: Rgba)
Set the clear color of the renderer.
Sourcepub fn set_key_capture(&mut self, key_capture: KeyCapture)
pub fn set_key_capture(&mut self, key_capture: KeyCapture)
Set how to handle capturing key events from the host.
Sourcepub fn baseview_window(&self) -> &WindowContext
pub fn baseview_window(&self) -> &WindowContext
Access the internal baseview window.
Sourcepub fn gl(&self) -> &Arc<Context> ⓘ
pub fn gl(&self) -> &Arc<Context> ⓘ
A reference to the underlying glow (OpenGL) context.
This can be used, for instance, to:
- Render things to offscreen buffers.
- Read the pixel buffer from the previous frame (glow::Context::read_pixels).
- Render things behind the egui windows.
Note that all egui painting is deferred to after the call to App::ui (egui only collects egui::Shapes and then egui-baseview paints them all in one go later on).